/*
 * Project name:
     nRFControlMaster.vtft
 * Generated by:
     Visual TFT
 * Date of creation
     3/8/2013
 * Time of creation
     11:06:41 AM
 * Test configuration:
     MCU:             LM4F232H5QD
     Dev.Board:       Mikromedia_Plus_for_Stellaris_ARM
                      http://www.mikroe.com/mikromedia/plus/stellaris/
     Oscillator:      80000000 Hz
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/
 */

#include "nRFControlMaster_objects.h"
#include "__Lib_nRF24L01.h"
#include "nRF24L01_defs.h"
#include "led_protocol.h"


sbit LED_R at GPIO_PORTG_DATA0_bit;
sbit LED_G at GPIO_PORTG_DATA1_bit;
sbit LED_B at GPIO_PORTG_DATA2_bit;


/*******************************************************************************
* nRF24L01+ connections
*******************************************************************************/
sbit nRF_CS at GPIO_PORTE_DATA0_bit;
sbit nRF_CE at GPIO_PORTG_DATA6_bit;
sbit nRF_IRQ at GPIO_PORTG_DATA7_bit;
sbit nRF_CS_Direction at GPIO_PORTE_DIR0_bit;
sbit nRF_CE_Direction at GPIO_PORTG_DIR6_bit;
sbit nRF_IRQ_Direction at GPIO_PORTG_DIR7_bit;

TnRF_Status nRFStatus;
TRF_Config rfConfig;

unsigned char rfState;

TLed leds[8];

TButton_Round *btns[8];

void InitLeds(void) {
  unsigned char i;
  
  for (i = 0; i < 8; i++)
  {
    leds[i]._state = 0;
    leds[i]._no    = i;
  }
}

void InitTimer2(){
  SYSCTL_RCGC1_TIMER2_bit = 1;
  EnableInterrupts();
  TIMER_CTL_TAEN_TIMER2_CTL_bit = 0;
  TIMER2_CFG   = 4;
  TIMER2_TAMR |= 2;
  TIMER2_TAPR  = 0;
  TIMER2_TAILR = 1280;
  NVIC_IntEnable(IVT_INT_TIMER2A_16_32_bit);
  TIMER_IMR_TATOIM_TIMER2_IMR_bit = 1;
}

void InitExt(){
  GPIO_PORTG_AFSEL = _GPIO_PINMASK_7;   // Enable alternate pin function
  GPIO_PORTG_IS    = 0;        // Edge sensitive
  GPIO_PORTG_IBE   = 0;
  GPIO_PORTG_IEV   = 0;        // Falling edge will trigger the event
  GPIO_PORTG_IM    = _GPIO_PINMASK_7;   // Set mask to PG7
  NVIC_IntEnable(IVT_INT_GPIOG);
}

void Timer2A_interrupt() iv IVT_INT_TIMER2A_16_32_bit ics ICS_AUTO {
  TIMER_ICR_TATOCINT_TIMER2_ICR_bit = 1;
  TIMER2_IRQ();
  TIMER_CTL_TAEN_TIMER2_CTL_bit = 0;
}

void GPIOInt() iv IVT_INT_GPIOG ics ICS_AUTO {
  GPIO_PORTG_ICR = _GPIO_PINMASK_7;

  nRF24L01_IRQ();
}

void InitRF()
{
  GPIO_Digital_Output(&GPIO_PORTG_DATA_BITS, _GPIO_PINMASK_0 | _GPIO_PINMASK_1 | _GPIO_PINMASK_2);

  nRF_CE = 0;
  nRF_CS = 1;

  InitTimer2();
  InitExt();

  SPI0_Init_Advanced(2000000, _SPI_MASTER, _SPI_8_BIT | _SPI_CLK_IDLE_LOW | _SPI_FIRST_CLK_EDGE_TRANSITION, &_GPIO_MODULE_SPI0_A245);
}

void main() {
  btns[0] = &ButtonRound8;
  btns[1] = &ButtonRound7;
  btns[2] = &ButtonRound6;
  btns[3] = &ButtonRound5;
  btns[4] = &ButtonRound4;
  btns[5] = &ButtonRound3;
  btns[6] = &ButtonRound2;
  btns[7] = &ButtonRound1;

  InitLeds();

  //nRF Config Settings
  rfConfig.autoTransmitDelay = nRF_AUTO_RETRANSMIT_DELAY_4000us; //250 + 15 * 250 = 4000us
  rfConfig.autoTransmitCount = nRF_AUTO_RETRANSMIT_COUNT_05;
  rfConfig.channel           = 64;
  rfConfig.outputPower       = nRF_OUTPUT_POWER_0dBm;
  rfConfig.dataRate          = nRF_DATA_RATE_1Mbps;

  Start_TP();
  
  nRF_Init();
  InitRF();
  Delay_ms(100);
  
  rfState = RF_STOP;
  
  nRF_TX_Mode_Init_Advanced(rfConfig.dataRate, rfConfig.autoTransmitDelay, rfConfig.autoTransmitCount, rfConfig.outputPower, rfConfig.channel);

  while (1) {
    Check_TP();
    
    if(rfState == RF_SEND_CMD)
    {
      if(nRF_Send_Packet())
      {
        LED_R = ~LED_R;
        Delay_ms(10);
        nRF_Process(&nRFStatus);

        if(nRFStatus._status == nRF_TX_DS)
        {
          LED_B = ~LED_B;
          LED_R = 0;
        
          rfState = RF_STOP;
        }
      }
    }
  }
}
